# Tools for Tax-Calculator Integration

## Automated unit test generation

`generate_taxcalc_unit_tests.py` has both a command-line interface and can be debugged (set `DEBUG_MODE` to true) to both generate random OpenFisca yaml-format unit tests (from the CPS) for calcfunctions, and to debug the produced tests in Tax-Calculator.
